# FM Synth Parameter Generator

Random machine learning experiments related to the classic Yamaha DX7

## Dexed

Dexed is a linux open source DX7 emulator and was used heavily in the testing of this project

## SYX

DX7 and it's similar instruments are programmable bt

format [found here](https://github.com/asb2m10/dexed/tree/master/Documentation
) under `sysexformat.txt`

## Dataset

Big thanks to Bobby Blues for collecting [these](http://bobbyblues.recup.ch/yamaha_dx7/dx7_patches.html) DX7 patches. This was the only data source



